summaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
Diffstat (limited to 'modules')
-rw-r--r--modules/benchmark.c4
-rw-r--r--modules/benchmark/bench_results.c2
-rw-r--r--modules/benchmark/benches.c2
-rw-r--r--modules/benchmark/blowfish2.c2
-rw-r--r--modules/benchmark/cryptohash.c2
-rw-r--r--modules/benchmark/drawing.c2
-rw-r--r--modules/benchmark/fft.c2
-rw-r--r--modules/benchmark/fib.c2
-rw-r--r--modules/benchmark/guibench.c2
-rw-r--r--modules/benchmark/raytrace.c2
-rw-r--r--modules/benchmark/sysbench.c2
-rw-r--r--modules/benchmark/zlib.c2
-rw-r--r--modules/computer.c5
-rw-r--r--modules/computer/alsa.c2
-rw-r--r--modules/computer/boots.c2
-rw-r--r--modules/computer/display.c2
-rw-r--r--modules/computer/environment.c2
-rw-r--r--modules/computer/filesystem.c2
-rw-r--r--modules/computer/groups.c2
-rw-r--r--modules/computer/languages.c2
-rw-r--r--modules/computer/loadavg.c2
-rw-r--r--modules/computer/memory.c2
-rw-r--r--modules/computer/memory_usage.c2
-rw-r--r--modules/computer/modules.c2
-rw-r--r--modules/computer/os.c2
-rw-r--r--modules/computer/ubuntu_flavors.c2
-rw-r--r--modules/computer/uptime.c2
-rw-r--r--modules/computer/users.c2
-rw-r--r--modules/devices.c4
-rw-r--r--modules/devices/alpha/processor.c2
-rw-r--r--modules/devices/arm/processor.c2
-rw-r--r--modules/devices/battery.c2
-rw-r--r--modules/devices/devicetree.c2
-rw-r--r--modules/devices/devicetree/pmac_data.c2
-rw-r--r--modules/devices/devicetree/rpi_data.c2
-rw-r--r--modules/devices/dmi.c2
-rw-r--r--modules/devices/dmi_memory.c2
-rw-r--r--modules/devices/firmware.c2
-rw-r--r--modules/devices/gpu.c2
-rw-r--r--modules/devices/ia64/processor.c2
-rw-r--r--modules/devices/inputdevices.c2
-rw-r--r--modules/devices/loongarch64/processor.c2
-rw-r--r--modules/devices/m68k/processor.c2
-rw-r--r--modules/devices/mips/processor.c2
-rw-r--r--modules/devices/monitors.c2
-rw-r--r--modules/devices/parisc/processor.c2
-rw-r--r--modules/devices/pci.c2
-rw-r--r--modules/devices/ppc/processor.c2
-rw-r--r--modules/devices/printers.c2
-rw-r--r--modules/devices/resources.c2
-rw-r--r--modules/devices/riscv/processor.c2
-rw-r--r--modules/devices/s390/processor.c2
-rw-r--r--modules/devices/sensors.c2
-rw-r--r--modules/devices/sh/processor.c2
-rw-r--r--modules/devices/sparc/processor.c2
-rw-r--r--modules/devices/storage.c2
-rw-r--r--modules/devices/usb.c2
-rw-r--r--modules/devices/x86/processor.c2
-rw-r--r--modules/network.c4
-rw-r--r--modules/network/net.c2
-rw-r--r--modules/network/nfs.c2
-rw-r--r--modules/network/samba.c2
62 files changed, 66 insertions, 67 deletions
diff --git a/modules/benchmark/bench_results.c b/modules/benchmark/bench_results.c
index 5403d963..e5212c71 100644
--- a/modules/benchmark/bench_results.c
+++ b/modules/benchmark/bench_results.c
@@ -6,7 +6,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/benches.c b/modules/benchmark/benches.c
index ff571548..26a03159 100644
--- a/modules/benchmark/benches.c
+++ b/modules/benchmark/benches.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/blowfish2.c b/modules/benchmark/blowfish2.c
index e3602acd..7426bef9 100644
--- a/modules/benchmark/blowfish2.c
+++ b/modules/benchmark/blowfish2.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/cryptohash.c b/modules/benchmark/cryptohash.c
index 17159d93..add7ca03 100644
--- a/modules/benchmark/cryptohash.c
+++ b/modules/benchmark/cryptohash.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/drawing.c b/modules/benchmark/drawing.c
index eaed934d..e92b9d62 100644
--- a/modules/benchmark/drawing.c
+++ b/modules/benchmark/drawing.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/fft.c b/modules/benchmark/fft.c
index 89b5d9c3..b7086e06 100644
--- a/modules/benchmark/fft.c
+++ b/modules/benchmark/fft.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/fib.c b/modules/benchmark/fib.c
index 7fe950d8..c61a945b 100644
--- a/modules/benchmark/fib.c
+++ b/modules/benchmark/fib.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/guibench.c b/modules/benchmark/guibench.c
index b97baf41..9ff50210 100644
--- a/modules/benchmark/guibench.c
+++ b/modules/benchmark/guibench.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/raytrace.c b/modules/benchmark/raytrace.c
index 928af3fa..a1abfcd5 100644
--- a/modules/benchmark/raytrace.c
+++ b/modules/benchmark/raytrace.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/sysbench.c b/modules/benchmark/sysbench.c
index 75b9e9f8..70db03e6 100644
--- a/modules/benchmark/sysbench.c
+++ b/modules/benchmark/sysbench.c
@@ -5,7 +5,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark/zlib.c b/modules/benchmark/zlib.c
index 60d57c49..2045969f 100644
--- a/modules/benchmark/zlib.c
+++ b/modules/benchmark/zlib.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/alsa.c b/modules/computer/alsa.c
index d3a6bbcd..f74d2752 100644
--- a/modules/computer/alsa.c
+++ b/modules/computer/alsa.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/boots.c b/modules/computer/boots.c
index 3d6492d6..5621e4e9 100644
--- a/modules/computer/boots.c
+++ b/modules/computer/boots.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/display.c b/modules/computer/display.c
index 56b68442..98cb7bf7 100644
--- a/modules/computer/display.c
+++ b/modules/computer/display.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/environment.c b/modules/computer/environment.c
index 697bf38f..2f29c861 100644
--- a/modules/computer/environment.c
+++ b/modules/computer/environment.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/filesystem.c b/modules/computer/filesystem.c
index db5bbe97..e9c84811 100644
--- a/modules/computer/filesystem.c
+++ b/modules/computer/filesystem.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/groups.c b/modules/computer/groups.c
index 75b7f645..9371e211 100644
--- a/modules/computer/groups.c
+++ b/modules/computer/groups.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/languages.c b/modules/computer/languages.c
index 97223dda..b2d4910f 100644
--- a/modules/computer/languages.c
+++ b/modules/computer/languages.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/loadavg.c b/modules/computer/loadavg.c
index c3faaaed..802ae2aa 100644
--- a/modules/computer/loadavg.c
+++ b/modules/computer/loadavg.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/memory.c b/modules/computer/memory.c
index add2bafe..994e4040 100644
--- a/modules/computer/memory.c
+++ b/modules/computer/memory.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/memory_usage.c b/modules/computer/memory_usage.c
index 2693fbd9..12c62fe7 100644
--- a/modules/computer/memory_usage.c
+++ b/modules/computer/memory_usage.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/modules.c b/modules/computer/modules.c
index 451b5c1b..14028362 100644
--- a/modules/computer/modules.c
+++ b/modules/computer/modules.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/os.c b/modules/computer/os.c
index 1a367881..2e53fd7e 100644
--- a/modules/computer/os.c
+++ b/modules/computer/os.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/ubuntu_flavors.c b/modules/computer/ubuntu_flavors.c
index b1ff0758..ac67d665 100644
--- a/modules/computer/ubuntu_flavors.c
+++ b/modules/computer/ubuntu_flavors.c
@@ -5,7 +5,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/uptime.c b/modules/computer/uptime.c
index 6fd1fe8f..8aef1530 100644
--- a/modules/computer/uptime.c
+++ b/modules/computer/uptime.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/computer/users.c b/modules/computer/users.c
index 35291ca5..75e24f26 100644
--- a/modules/computer/users.c
+++ b/modules/computer/users.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/alpha/processor.c b/modules/devices/alpha/processor.c
index c820a94a..0e625316 100644
--- a/modules/devices/alpha/processor.c
+++ b/modules/devices/alpha/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/arm/processor.c b/modules/devices/arm/processor.c
index d3191ebc..9446108d 100644
--- a/modules/devices/arm/processor.c
+++ b/modules/devices/arm/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/battery.c b/modules/devices/battery.c
index bc3f70f8..3424fa9d 100644
--- a/modules/devices/battery.c
+++ b/modules/devices/battery.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/devicetree.c b/modules/devices/devicetree.c
index 6999da3f..43fc0a50 100644
--- a/modules/devices/devicetree.c
+++ b/modules/devices/devicetree.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/devicetree/pmac_data.c b/modules/devices/devicetree/pmac_data.c
index 51298a17..8c5471f0 100644
--- a/modules/devices/devicetree/pmac_data.c
+++ b/modules/devices/devicetree/pmac_data.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/devicetree/rpi_data.c b/modules/devices/devicetree/rpi_data.c
index 4ef729a4..63daa7f3 100644
--- a/modules/devices/devicetree/rpi_data.c
+++ b/modules/devices/devicetree/rpi_data.c
@@ -6,7 +6,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/dmi.c b/modules/devices/dmi.c
index 4fca33c1..c1915638 100644
--- a/modules/devices/dmi.c
+++ b/modules/devices/dmi.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/dmi_memory.c b/modules/devices/dmi_memory.c
index 3f99d650..8d2ecadf 100644
--- a/modules/devices/dmi_memory.c
+++ b/modules/devices/dmi_memory.c
@@ -5,7 +5,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/firmware.c b/modules/devices/firmware.c
index 4f7fb744..ea6ce532 100644
--- a/modules/devices/firmware.c
+++ b/modules/devices/firmware.c
@@ -6,7 +6,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/gpu.c b/modules/devices/gpu.c
index eee9ee25..16267536 100644
--- a/modules/devices/gpu.c
+++ b/modules/devices/gpu.c
@@ -6,7 +6,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/ia64/processor.c b/modules/devices/ia64/processor.c
index 3cf14d7f..f31813bc 100644
--- a/modules/devices/ia64/processor.c
+++ b/modules/devices/ia64/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/inputdevices.c b/modules/devices/inputdevices.c
index 65f28130..a4b4ac73 100644
--- a/modules/devices/inputdevices.c
+++ b/modules/devices/inputdevices.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/loongarch64/processor.c b/modules/devices/loongarch64/processor.c
index b207a9fd..08f3645e 100644
--- a/modules/devices/loongarch64/processor.c
+++ b/modules/devices/loongarch64/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/m68k/processor.c b/modules/devices/m68k/processor.c
index 5dd92867..a9d71835 100644
--- a/modules/devices/m68k/processor.c
+++ b/modules/devices/m68k/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/mips/processor.c b/modules/devices/mips/processor.c
index 082c7297..112a3c3b 100644
--- a/modules/devices/mips/processor.c
+++ b/modules/devices/mips/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/monitors.c b/modules/devices/monitors.c
index dad86d6f..043c0d3b 100644
--- a/modules/devices/monitors.c
+++ b/modules/devices/monitors.c
@@ -5,7 +5,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/parisc/processor.c b/modules/devices/parisc/processor.c
index 8493a5ca..c749bc5a 100644
--- a/modules/devices/parisc/processor.c
+++ b/modules/devices/parisc/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/pci.c b/modules/devices/pci.c
index 64966b80..be816c46 100644
--- a/modules/devices/pci.c
+++ b/modules/devices/pci.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/ppc/processor.c b/modules/devices/ppc/processor.c
index 6e4a964f..12c575a6 100644
--- a/modules/devices/ppc/processor.c
+++ b/modules/devices/ppc/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/printers.c b/modules/devices/printers.c
index bb68a188..655d73c5 100644
--- a/modules/devices/printers.c
+++ b/modules/devices/printers.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/resources.c b/modules/devices/resources.c
index 36a413a4..1436192d 100644
--- a/modules/devices/resources.c
+++ b/modules/devices/resources.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/riscv/processor.c b/modules/devices/riscv/processor.c
index b2191a07..f2e51c91 100644
--- a/modules/devices/riscv/processor.c
+++ b/modules/devices/riscv/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/s390/processor.c b/modules/devices/s390/processor.c
index 58ec6e8b..e4f2b303 100644
--- a/modules/devices/s390/processor.c
+++ b/modules/devices/s390/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/sensors.c b/modules/devices/sensors.c
index 608975ed..095f0bc4 100644
--- a/modules/devices/sensors.c
+++ b/modules/devices/sensors.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/sh/processor.c b/modules/devices/sh/processor.c
index 8dc339fb..a5ce3e0a 100644
--- a/modules/devices/sh/processor.c
+++ b/modules/devices/sh/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/sparc/processor.c b/modules/devices/sparc/processor.c
index b0cf385a..76f4b0e0 100644
--- a/modules/devices/sparc/processor.c
+++ b/modules/devices/sparc/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/storage.c b/modules/devices/storage.c
index 970558ee..bbf9b195 100644
--- a/modules/devices/storage.c
+++ b/modules/devices/storage.c
@@ -5,7 +5,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/usb.c b/modules/devices/usb.c
index 001c347e..c6a5ab39 100644
--- a/modules/devices/usb.c
+++ b/modules/devices/usb.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/devices/x86/processor.c b/modules/devices/x86/processor.c
index d9f4780b..62d32135 100644
--- a/modules/devices/x86/processor.c
+++ b/modules/devices/x86/processor.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/network/net.c b/modules/network/net.c
index 0a71a4c0..535461e4 100644
--- a/modules/network/net.c
+++ b/modules/network/net.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/network/nfs.c b/modules/network/nfs.c
index 6d9e4aa3..67095f92 100644
--- a/modules/network/nfs.c
+++ b/modules/network/nfs.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/network/samba.c b/modules/network/samba.c
index e75b1ee6..e14742ea 100644
--- a/modules/network/samba.c
+++ b/modules/network/samba.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
diff --git a/modules/benchmark.c b/modules/benchmark.c
index 50ba7d2d..c53790fa 100644
--- a/modules/benchmark.c
+++ b/modules/benchmark.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, version 2.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -740,7 +740,7 @@ const ModuleAbout *hi_module_get_about(void)
.author = "L. A. F. Pereira",
.description = N_("Perform tasks and compare with other systems"),
.version = VERSION,
- .license = "GNU GPL version 2",
+ .license = "GNU GPL version 2 or later.",
};
return &ma;
@@ -4,7 +4,7 @@
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
diff --git a/modules/computer.c b/modules/computer.c
index da18b5c2..a235efc9 100644
--- a/modules/computer.c
+++ b/modules/computer.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, version 2.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1083,8 +1083,7 @@ const ModuleAbout *hi_module_get_about(void)
.author = "L. A. F. Pereira",
.description = N_("Gathers high-level computer information"),
.version = VERSION,
- .license = "GNU GPL version 2",
- };
+ .license = "GNU GPL version 2 or later.",};
return &ma;
}
@@ -4,7 +4,7 @@
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
diff --git a/modules/devices.c b/modules/devices.c
index 93063ad4..a44cdb0c 100644
--- a/modules/devices.c
+++ b/modules/devices.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, version 2.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -896,7 +896,7 @@ const ModuleAbout *hi_module_get_about(void)
.author = "L. A. F. Pereira",
.description = N_("Gathers information about hardware devices"),
.version = VERSION,
- .license = "GNU GPL version 2",
+ .license = "GNU GPL version 2 or later.",
};
return &ma;
@@ -4,7 +4,7 @@
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,
diff --git a/modules/network.c b/modules/network.c
index b91d8090..4b65e0aa 100644
--- a/modules/network.c
+++ b/modules/network.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, version 2.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -440,7 +440,7 @@ const ModuleAbout *hi_module_get_about(void)
.description =
N_("Gathers information about this computer's network connection"),
.version = VERSION,
- .license = "GNU GPL version 2",
+ .license = "GNU GPL version 2 or later.",
};
return &ma;
@@ -4,7 +4,7 @@
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,